The following commit has been merged in the master branch:
commit 33eb7e05e5b7e0f426570f2b8622aa457fa23b95
Author: Michael Stapelberg <[email protected]>
Date:   Sun Jun 30 21:45:41 2013 +0200

    c/systemd.pm: allow systemctl --daemon-reload lines
    
    Signed-off-by: Niels Thykier <[email protected]>

diff --git a/checks/systemd.pm b/checks/systemd.pm
index e5292dc..e0170c2 100644
--- a/checks/systemd.pm
+++ b/checks/systemd.pm
@@ -254,8 +254,9 @@ sub check_maintainer_scripts {
             # skip comments
             next if substr ($_, 0, $-[0]) =~ /#/;
 
-            ## systemctl should not be called in maintainer scripts at all.
-            if (m/\bsystemctl\b/) {
+            # systemctl should not be called in maintainer scripts at all,
+            # except for systemctl --daemon-reload calls.
+            if (m/\bsystemctl\b/ && !/daemon-reload/) {
                 tag 'maintainer-script-calls-systemctl', $file;
             }
         }

-- 
Debian package checker


-- 
To UNSUBSCRIBE, email to [email protected]
with a subject of "unsubscribe". Trouble? Contact [email protected]
Archive: http://lists.debian.org/[email protected]

Reply via email to